@@ -1,23 +1,26 @@
+from __future__ import annotations
+
+from collections.abc import Iterable
 from datetime import date
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any
 
 import pandas as pd
-from databento.common.enums import Dataset, Encoding, FeedMode, Schema, SType
-from databento.common.parsing import (
-    datetime_to_string,
-    optional_date_to_string,
-    optional_datetime_to_string,
-    optional_symbols_list_to_string,
-)
-from databento.common.validation import (
-    validate_enum,
-    validate_maybe_enum,
-    validate_semantic_string,
-)
-from databento.historical.api import API_VERSION
-from databento.historical.http import BentoHttpAPI
+from databento_dbn import Encoding
+from databento_dbn import Schema
+from databento_dbn import SType
 from requests import Response
 
+from databento.common import API_VERSION
+from databento.common.enums import FeedMode
+from databento.common.http import BentoHttpAPI
+from databento.common.parsing import datetime_to_string
+from databento.common.parsing import optional_date_to_string
+from databento.common.parsing import optional_datetime_to_string
+from databento.common.parsing import optional_symbols_list_to_list
+from databento.common.publishers import Dataset
+from databento.common.validation import validate_enum
+from databento.common.validation import validate_semantic_string
+
 
 class MetadataHttpAPI(BentoHttpAPI):
     """
@@ -28,17 +31,17 @@ class MetadataHttpAPI(BentoHttpAPI):
         super().__init__(key=key, gateway=gateway)
         self._base_url = gateway + f"/v{API_VERSION}/metadata"
 
-    def list_publishers(self) -> Dict[str, int]:
+    def list_publishers(self) -> list[dict[str, Any]]:
         """
         Request all publishers from Databento.
 
         Makes a `GET /metadata.list_publishers` HTTP request.
 
-        Use this method to list the mappings of publisher names to publisher IDs.
+        Use this method to list the details of publishers, including their dataset and venue mappings.
 
         Returns
         -------
-        Dict[str, int]
+        list[dict[str, Any]]
 
         """
         response: Response = self._get(
@@ -49,15 +52,15 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def list_datasets(
         self,
-        start_date: Optional[Union[date, str]] = None,
-        end_date: Optional[Union[date, str]] = None,
-    ) -> List[str]:
+        start_date: date | str | None = None,
+        end_date: date | str | None = None,
+    ) -> list[str]:
         """
-        Request all available datasets from Databento.
+        Request all available dataset codes from Databento.
 
         Makes a `GET /metadata.list_datasets` HTTP request.
 
-        Use this method to list the _names_ of all available datasets, so you
+        Use this method to list the available dataset _codes (string identifiers), so you
         can use other methods which take the `dataset` parameter.
 
         Parameters
@@ -71,10 +74,10 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        List[str]
+        list[str]
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
+        params: list[tuple[str, str | None]] = [
             ("start_date", optional_date_to_string(start_date)),
             ("end_date", optional_date_to_string(end_date)),
         ]
@@ -86,12 +89,7 @@ class MetadataHttpAPI(BentoHttpAPI):
         )
         return response.json()
 
-    def list_schemas(
-        self,
-        dataset: Union[Dataset, str],
-        start_date: Optional[Union[date, str]] = None,
-        end_date: Optional[Union[date, str]] = None,
-    ) -> List[str]:
+    def list_schemas(self, dataset: Dataset | str) -> list[str]:
         """
         Request all available data schemas from Databento.
 
@@ -101,22 +99,14 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code (string identifier) for the request.
-        start_date : date or str, optional
-            The start date (UTC) for the request range.
-            If `None` then first date available.
-        end_date : date or str, optional
-            The end date (UTC) for the request range.
-            If `None` then last date available.
 
         Returns
         -------
-        List[str]
+        list[str]
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("start_date", optional_date_to_string(start_date)),
-            ("end_date", optional_date_to_string(end_date)),
         ]
 
         response: Response = self._get(
@@ -128,37 +118,30 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def list_fields(
         self,
-        dataset: Union[Dataset, str],
-        schema: Optional[Union[Schema, str]] = None,
-        encoding: Optional[Union[Encoding, str]] = None,
-    ) -> Dict[str, Dict[str, str]]:
+        schema: Schema | str,
+        encoding: Encoding | str,
+    ) -> list[dict[str, Any]]:
         """
-        Request all fields for a dataset, schema and encoding from Databento.
+        List all fields for a particular schema and encoding from Databento.
 
         Makes a `GET /metadata.list_fields` HTTP request.
 
-        The `schema` and `encoding` parameters act as optional filters. All
-        metadata for that parameter is returned if they are not specified.
-
         Parameters
         ----------
-        dataset : Dataset or str
-            The dataset code (string identifier) for the request.
-        schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, optional  # noqa
+        schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'},
             The data record schema for the request.
-        encoding : Encoding or str {'dbn', 'csv', 'json'}, optional
+        encoding : Encoding or str {'dbn', 'csv', 'json'}
             The data encoding.
 
         Returns
         -------
-        Dict[str, Dict[str, str]]
-            A mapping of dataset to encoding to schema to field to data type.
+        list[dict[str, Any]]
+            A list of field details.
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
-            ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("schema", validate_maybe_enum(schema, Schema, "schema")),
-            ("encoding", validate_maybe_enum(encoding, Encoding, "encoding")),
+        params: list[tuple[str, str | Any]] = [
+            ("schema", validate_enum(schema, Schema, "schema")),
+            ("encoding", validate_enum(encoding, Encoding, "encoding")),
         ]
 
         response: Response = self._get(
@@ -168,48 +151,13 @@ class MetadataHttpAPI(BentoHttpAPI):
         )
         return response.json()
 
-    def list_encodings(self) -> List[str]:
-        """
-        Request all available data encodings from Databento.
-
-        Makes a `GET /metadata.list_encodings` HTTP request.
-
-        Returns
-        -------
-        List[str]
-
-        """
-        response: Response = self._get(
-            url=self._base_url + ".list_encodings",
-            basic_auth=True,
-        )
-        return response.json()
-
-    def list_compressions(self) -> List[str]:
-        """
-        Request all available data compression modes from Databento.
-
-        Makes a `GET /metadata.list_compressions` HTTP request.
-
-        Returns
-        -------
-        List[str]
-
-        """
-        response: Response = self._get(
-            url=self._base_url + ".list_compressions",
-            basic_auth=True,
-        )
-        return response.json()
-
     def list_unit_prices(
         self,
-        dataset: Union[Dataset, str],
-        mode: Optional[Union[FeedMode, str]] = None,
-        schema: Optional[Union[Schema, str]] = None,
-    ) -> Union[float, Dict[str, Any]]:
+        dataset: Dataset | str,
+    ) -> list[dict[str, Any]]:
         """
-        List unit prices for each data schema in dollars per gigabyte.
+        List unit prices for each feed mode and data schema in US dollars per
+        gigabyte.
 
         Makes a `GET /metadata.list_unit_prices` HTTP request.
 
@@ -217,22 +165,15 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code for the request.
-        mode : FeedMode or str {'live', 'historical-streaming', 'historical'}, optional
-            The data feed mode for the request.
-        schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, optional  # noqa
-            The data record schema for the request.
 
         Returns
         -------
-        float or Dict[str, Any]
-            If both `mode` and `schema` are specified, the unit price is returned as a single number.
-            Otherwise, return a map of feed mode to schema to unit price.
+        list[dict[str, Any]]
+            A list of maps of feed mode to schema to unit price.
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
+        params: list[tuple[str, Dataset | str]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("mode", validate_maybe_enum(mode, FeedMode, "mode")),
-            ("schema", validate_maybe_enum(schema, Schema, "schema")),
         ]
 
         response: Response = self._get(
@@ -244,10 +185,10 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def get_dataset_condition(
         self,
-        dataset: Union[Dataset, str],
-        start_date: Optional[Union[date, str]] = None,
-        end_date: Optional[Union[date, str]] = None,
-    ) -> Dict[str, Any]:
+        dataset: Dataset | str,
+        start_date: date | str | None = None,
+        end_date: date | str | None = None,
+    ) -> dict[str, Any]:
         """
         Get the per date dataset conditions from Databento.
 
@@ -268,10 +209,10 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        Dict[str, Any]
+        dict[str, Any]
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
             ("start_date", optional_date_to_string(start_date)),
             ("end_date", optional_date_to_string(end_date)),
@@ -286,8 +227,8 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def get_dataset_range(
         self,
-        dataset: Union[Dataset, str],
-    ) -> Dict[str, str]:
+        dataset: Dataset | str,
+    ) -> dict[str, str]:
         """
         Request the available range for the dataset from Databento.
 
@@ -300,11 +241,11 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         Returns
         -------
-        Dict[str, str]
+        dict[str, str]
             The available range for the dataset.
 
         """
-        params: List[Tuple[str, Optional[str]]] = [
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
         ]
 
@@ -318,13 +259,13 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def get_record_count(
         self,
-        dataset: Union[Dataset, str],
-        start: Union[pd.Timestamp, date, str, int],
-        end: Union[pd.Timestamp, date, str, int],
-        symbols: Optional[Union[List[str], str]] = None,
-        schema: Union[Schema, str] = "trades",
-        stype_in: Optional[Union[SType, str]] = "native",
-        limit: Optional[int] = None,
+        dataset: Dataset | str,
+        start: pd.Timestamp | date | str | int,
+        end: pd.Timestamp | date | str | int | None = None,
+        symbols: Iterable[str | int] | str | int | None = None,
+        schema: Schema | str = "trades",
+        stype_in: SType | str = "raw_symbol",
+        limit: int | None = None,
     ) -> int:
         """
         Request the count of data records from Databento.
@@ -336,17 +277,21 @@ class MetadataHttpAPI(BentoHttpAPI):
         dataset : Dataset or str
             The dataset code for the request.
         start : pd.Timestamp or date or str or int
-            The start datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+            The start datetime for the request range (inclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int
-            The end datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+        end : pd.Timestamp or date or str or int, optional
+            The end datetime for the request range (exclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        symbols : List[Union[str, int]] or str, optional
-            The product symbols to filter for. Takes up to 2,000 symbols per request.
-            If 'ALL_SYMBOLS' or `None` then will be for **all** symbols.
+            Values are forward filled based on the resolution provided.
+            Defaults to the same value as `start`.
+        symbols : Iterable[str | int] or str or int, optional
+            The instrument symbols to filter for. Takes up to 2,000 symbols per request.
+            If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
         schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, default 'trades'  # noqa
             The data record schema for the request.
-        stype_in : SType or str, default 'native'
+        stype_in : SType or str, default 'raw_symbol'
             The input symbology type to resolve from.
         limit : int, optional
             The maximum number of records to return. If `None` then no limit.
@@ -358,10 +303,10 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
-        symbols_list = optional_symbols_list_to_string(symbols, stype_in_valid)
-        params: List[Tuple[str, Optional[str]]] = [
+        symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
-            ("symbols", symbols_list),
+            ("symbols", ",".join(symbols_list)),
             ("schema", str(validate_enum(schema, Schema, "schema"))),
             ("start", optional_datetime_to_string(start)),
             ("end", optional_datetime_to_string(end)),
@@ -382,13 +327,13 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def get_billable_size(
         self,
-        dataset: Union[Dataset, str],
-        start: Union[pd.Timestamp, date, str, int],
-        end: Union[pd.Timestamp, date, str, int],
-        symbols: Optional[Union[List[str], str]] = None,
-        schema: Union[Schema, str] = "trades",
-        stype_in: Optional[Union[SType, str]] = "native",
-        limit: Optional[int] = None,
+        dataset: Dataset | str,
+        start: pd.Timestamp | date | str | int,
+        end: pd.Timestamp | date | str | int | None = None,
+        symbols: Iterable[str | int] | str | int | None = None,
+        schema: Schema | str = "trades",
+        stype_in: SType | str = "raw_symbol",
+        limit: int | None = None,
     ) -> int:
         """
         Request the billable uncompressed raw binary size for historical
@@ -400,18 +345,22 @@ class MetadataHttpAPI(BentoHttpAPI):
         ----------
         dataset : Dataset or str
             The dataset code for the request.
-        start : pd.Timestamp or date or str or int, optional
-            The start datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+        start : pd.Timestamp or date or str or int
+            The start datetime for the request range (inclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
         end : pd.Timestamp or date or str or int, optional
-            The end datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+            The end datetime for the request range (exclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        symbols : List[Union[str, int]] or str, optional
-            The product symbols to filter for. Takes up to 2,000 symbols per request.
-            If 'ALL_SYMBOLS' or `None` then will be for **all** symbols.
+            Values are forward filled based on the resolution provided.
+            Defaults to the same value as `start`.
+        symbols : Iterable[str | int] or str or int, optional
+            The instrument symbols to filter for. Takes up to 2,000 symbols per request.
+            If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
         schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, default 'trades'  # noqa
             The data record schema for the request.
-        stype_in : SType or str, default 'native'
+        stype_in : SType or str, default 'raw_symbol'
             The input symbology type to resolve from.
         limit : int, optional
             The maximum number of records to return. If `None` then no limit.
@@ -423,15 +372,15 @@ class MetadataHttpAPI(BentoHttpAPI):
 
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
-        symbols_list = optional_symbols_list_to_string(symbols, stype_in_valid)
-        params: List[Tuple[str, Optional[str]]] = [
+        symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
             ("start", datetime_to_string(start)),
-            ("end", datetime_to_string(end)),
-            ("symbols", symbols_list),
+            ("end", optional_datetime_to_string(end)),
+            ("symbols", ",".join(symbols_list)),
             ("schema", str(validate_enum(schema, Schema, "schema"))),
             ("stype_in", str(stype_in_valid)),
-            ("stype_out", str(SType.PRODUCT_ID)),
+            ("stype_out", str(SType.INSTRUMENT_ID)),
         ]
 
         if limit is not None:
@@ -447,18 +396,18 @@ class MetadataHttpAPI(BentoHttpAPI):
 
     def get_cost(
         self,
-        dataset: Union[Dataset, str],
-        start: Union[pd.Timestamp, date, str, int],
-        end: Union[pd.Timestamp, date, str, int],
-        mode: Union[FeedMode, str] = "historical-streaming",
-        symbols: Optional[Union[List[str], str]] = None,
-        schema: Union[Schema, str] = "trades",
-        stype_in: Optional[Union[SType, str]] = "native",
-        limit: Optional[int] = None,
+        dataset: Dataset | str,
+        start: pd.Timestamp | date | str | int,
+        end: pd.Timestamp | date | str | int | None = None,
+        mode: FeedMode | str = "historical-streaming",
+        symbols: Iterable[str | int] | str | int | None = None,
+        schema: Schema | str = "trades",
+        stype_in: SType | str = "raw_symbol",
+        limit: int | None = None,
     ) -> float:
         """
-        Request the cost in US Dollars for historical streaming or batched files
-        from Databento.
+        Request the cost in US dollars for historical streaming or batched
+        files from Databento.
 
         Makes a `GET /metadata.get_cost` HTTP request.
 
@@ -467,19 +416,23 @@ class MetadataHttpAPI(BentoHttpAPI):
         dataset : Dataset or str
             The dataset code for the request.
         start : pd.Timestamp or date or str or int
-            The start datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+            The start datetime for the request range (inclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
-        end : pd.Timestamp or date or str or int
-            The end datetime for the request range. Assumes UTC as timezone unless otherwise specified.
+        end : pd.Timestamp or date or str or int, optional
+            The end datetime for the request range (exclusive).
+            Assumes UTC as timezone unless otherwise specified.
             If an integer is passed, then this represents nanoseconds since the UNIX epoch.
+            Values are forward filled based on the resolution provided.
+            Defaults to the same value as `start`.
         mode : FeedMode or str {'live', 'historical-streaming', 'historical'}, default 'historical-streaming'
             The data feed mode for the request.
-        symbols : List[Union[str, int]] or str, optional
-            The product symbols to filter for. Takes up to 2,000 symbols per request.
-            If 'ALL_SYMBOLS' or `None` then will be for **all** symbols.
+        symbols : Iterable[str | int] or str or int, optional
+            The instrument symbols to filter for. Takes up to 2,000 symbols per request.
+            If 'ALL_SYMBOLS' or `None` then will select **all** symbols.
         schema : Schema or str {'mbo', 'mbp-1', 'mbp-10', 'trades', 'tbbo', 'ohlcv-1s', 'ohlcv-1m', 'ohlcv-1h', 'ohlcv-1d', 'definition', 'statistics', 'status'}, default 'trades'  # noqa
             The data record schema for the request.
-        stype_in : SType or str, default 'native'
+        stype_in : SType or str, default 'raw_symbol'
             The input symbology type to resolve from.
         limit : int, optional
             The maximum number of records to return. If `None` then no limit.
@@ -487,19 +440,19 @@ class MetadataHttpAPI(BentoHttpAPI):
         Returns
         -------
         float
-            The cost in US Dollars.
+            The cost in US dollars.
 
         """
         stype_in_valid = validate_enum(stype_in, SType, "stype_in")
-        symbols_list = optional_symbols_list_to_string(symbols, stype_in_valid)
-        params: List[Tuple[str, str]] = [
+        symbols_list = optional_symbols_list_to_list(symbols, stype_in_valid)
+        params: list[tuple[str, str | None]] = [
             ("dataset", validate_semantic_string(dataset, "dataset")),
             ("start", datetime_to_string(start)),
-            ("end", datetime_to_string(end)),
-            ("symbols", symbols_list),
+            ("end", optional_datetime_to_string(end)),
+            ("symbols", ",".join(symbols_list)),
             ("schema", str(validate_enum(schema, Schema, "schema"))),
             ("stype_in", str(stype_in_valid)),
-            ("stype_out", str(SType.PRODUCT_ID)),
+            ("stype_out", str(SType.INSTRUMENT_ID)),
             ("mode", validate_enum(mode, FeedMode, "mode")),
         ]
 
