@@ -1,13 +1,14 @@
+from __future__ import annotations
+
 import logging
 import os
-from typing import Optional, Union
 
 from databento.common.enums import HistoricalGateway
 from databento.common.validation import validate_gateway
 from databento.historical.api.batch import BatchHttpAPI
 from databento.historical.api.metadata import MetadataHttpAPI
 from databento.historical.api.symbology import SymbologyHttpAPI
-from databento.historical.api.timeseries import TimeSeriesHttpAPI
+from databento.historical.api.timeseries import TimeseriesHttpAPI
 
 
 logger = logging.getLogger(__name__)
@@ -31,12 +32,13 @@ class Historical:
     --------
     > import databento as db
     > client = db.Historical('YOUR_API_KEY')
+
     """
 
     def __init__(
         self,
-        key: Optional[str] = None,
-        gateway: Union[HistoricalGateway, str] = HistoricalGateway.BO1,
+        key: str | None = None,
+        gateway: HistoricalGateway | str = HistoricalGateway.BO1,
     ):
         if key is None:
             key = os.environ.get("DATABENTO_API_KEY")
@@ -54,7 +56,7 @@ class Historical:
         self.batch = BatchHttpAPI(key=key, gateway=gateway)
         self.metadata = MetadataHttpAPI(key=key, gateway=gateway)
         self.symbology = SymbologyHttpAPI(key=key, gateway=gateway)
-        self.timeseries = TimeSeriesHttpAPI(key=key, gateway=gateway)
+        self.timeseries = TimeseriesHttpAPI(key=key, gateway=gateway)
 
         # Not logging security sensitive `key`
         logger.info("Initialized %s(gateway=%s)", type(self).__name__, self.gateway)
